@@ -8,6 +8,7 @@ from .metrics import HttpRequestMetric
 from .middleware import PrometheusMiddleware
 from .view import prometheus_view
 
+
 def add_prometheus_middleware(
         app: Application,
         *,
@@ -17,7 +18,7 @@ def add_prometheus_middleware(
         metrics_path: Optional[str] = '/metrics'
 ) -> Application:
     """Adds prometheus middleware as the first middleware.
-    
+
     Args:
         app (Application): The ASGI application
         metric_type (Optional[Type[HttpRequestMetric]], optional): An optional
@@ -28,12 +29,13 @@ def add_prometheus_middleware(
             None.
         metrics_path (Optional[str], optional): The path from which the metrics
             will be served. Defaults to '/metrics'.
-    
+
     Returns:
         Application: The ASGI application
     """
 
-    prometheus_middleware = PrometheusMiddleware(metric_type=metric_type, host=host, app_name=app_name)
+    prometheus_middleware = PrometheusMiddleware(
+        metric_type=metric_type, host=host, app_name=app_name)
     app.middlewares.insert(0, prometheus_middleware)
 
     if metrics_path:
